@@ -1,7 +1,7 @@
 from datetime import date
-from typing import Dict, Any
+from typing import Any, Dict, Optional
 
-from pandas import DataFrame, Series, Grouper
+from pandas import DataFrame, Grouper, Series
 from plotly import graph_objects as go
 from plotly.subplots import make_subplots
 
@@ -61,13 +61,13 @@ def calplot(
     month_lines_color: str = "#9e9e9e",
     gap: int = 1,
     years_title: bool = False,
-    width: int = 800,
     colorscale: str = "greens",
     title: str = "",
     month_lines: bool = True,
     total_height: int = None,
     space_between_plots: float = 0.08,
     showscale: bool = False,
+    text: Optional[str] = None,
 ) -> go.Figure:
     """
     Yearly Calendar Heatmap
@@ -106,9 +106,6 @@ def calplot(
         if true will add a title for each subplot with the
         correspondent year
 
-    width : int = 800
-        controls the width of the plot
-
     colorscale : str = "greens"
         controls the colorscale for the calendar, works
         with all the standard Plotly Colorscales and also
@@ -128,6 +125,9 @@ def calplot(
     showscale: bool = False
         if True, a color legend will be created.
         Thanks to @ghhar98!
+
+    text: Optional[str] = None
+        The name of the column in data to include in hovertext.
     """
     unique_years = data[x].dt.year.unique()
     unique_years_amount = len(unique_years)
@@ -163,11 +163,12 @@ def calplot(
             year=year,
             fig=fig,
             dark_theme=dark_theme,
-            width=width,
             gap=gap,
             title=title,
             row=i,
             total_height=total_height,
+            text=None if text is None else selected_year_data[text].tolist(),
+            text_name=text,
         )
 
     fig = apply_general_colorscaling(data, y, fig)
@@ -184,7 +185,6 @@ def month_calplot(
     name: str = "y",
     dark_theme: bool = False,
     gap: int = 2,
-    width: int = 400,
     colorscale: str = "greens",
     title: str = "",
     year_height: int = 30,
@@ -213,9 +213,6 @@ def month_calplot(
     gap : int = 2
         controls the gap bewteen monthly squares
 
-    width : int = 400
-        controls the width of the plot
-
     colorscale : str = "greens"
         controls the colorscale for the calendar, works
         with all the standard Plotly Colorscales and also
@@ -256,7 +253,6 @@ def month_calplot(
 
     layout = _get_subplot_layout(
         dark_theme=dark_theme,
-        width=width,
         height=total_height,
         title=title,
         yaxis={
